@@ -212,6 +212,7 @@ __all__ = (
     "GetTransitGatewayPrefixListReferencesPaginatorName",
     "GetTransitGatewayRouteTableAssociationsPaginatorName",
     "GetTransitGatewayRouteTablePropagationsPaginatorName",
+    "GetVpnConnectionDeviceTypesPaginatorName",
     "HostRecoveryType",
     "HostTenancyType",
     "HttpTokensStateType",
@@ -690,6 +691,7 @@ GetTransitGatewayRouteTableAssociationsPaginatorName = Literal[
 GetTransitGatewayRouteTablePropagationsPaginatorName = Literal[
     "get_transit_gateway_route_table_propagations"
 ]
+GetVpnConnectionDeviceTypesPaginatorName = Literal["get_vpn_connection_device_types"]
 HostRecoveryType = Literal["off", "on"]
 HostTenancyType = Literal["dedicated", "host"]
 HttpTokensStateType = Literal["optional", "required"]
